# Copyright © 2016 CNRS,
# Copyright © 2016 Université de Nantes.
# Author: Florian Blachère
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

VERSION=gnu
GFORTRAN_VER_MAJOR=$(shell gfortran -dumpversion 2> /dev/null | cut -d. -f 1)

MODCOMMAND=-J$(MODDIR)
FFLAGS+=-cpp -ffree-line-length-none
#FFLAGS+=-fexternal-blas
ifeq ($(shell [ $(GFORTRAN_VER_MAJOR) -ge 5 ] && echo 1), 1)
	FFLAGS+=-fdiagnostics-color=always
endif

ifeq ($(OMP),1)
	PREPROC+=-D_FC_PAR_OMP_
	FFLAGS+=-fopenmp
	LDFLAGS+=-lgomp
	VERSION:=$(VERSION)_omp
endif # OMP

ifeq ($(MPI),1)
	PREPROC+=-D_FC_PAR_MPI_
	VERSION:=$(VERSION)_mpi
endif # MPI

ifeq ($(PROFILING), 1)
	FFLAGS+=-pg -fbacktrace -g
	PREPROC+=-D_PROFILING_
	LDFLAGS+=-pg
	VERSION:=$(VERSION)_prof
endif # PROFILING

ifeq ($(COVERAGE), 1)
	FFLAGS+=-fbacktrace -g
	FFLAGS+=-fprofile-arcs -ftest-coverage
	PREPROC+=-D_COVERAGE_
	LDFLAGS+=-lgcov
	VERSION:=$(VERSION)_cov
endif # COVERAGE

ifeq ($(DEBUG), 1)
	PREPROC+=-D_DEBUG_
	FFLAGS+=-Wall -Wextra
	FFLAGS+=-g -O0
	FFLAGS+=-Wimplicit-interface -Wimplicit-procedure -Wintrinsics-std
	FFLAGS+=-Warray-temporaries -Wc-binding-type
	FFLAGS+=-Wcharacter-truncation -Wline-truncation
	FFLAGS+=-Wconversion-extra -Wtabs
	FFLAGS+=-Wuninitialized
	FFLAGS+=-Wreal-q-constant -Wsurprising
ifeq ($(shell [ $(GFORTRAN_VER_MAJOR) -ge 5 ] && echo 1), 1)
		FFLAGS+=-Wuse-without-only
endif
	FFLAGS+=-Wrealloc-lhs -Wrealloc-lhs-all
	FFLAGS+=-fbacktrace -fcheck=all
	FFLAGS+=-ffpe-trap=zero,overflow,underflow,invalid
	#FFLAGS+=-std=f2008 -fall-intrinsics
	#FFLAGS+=-finit-local-zero
	#FFLAGS+=-finit-real=snan
	FFLAGS+=-fimplicit-none
	VERSION:=$(VERSION)_g
else
	#FFLAGS+=-O0 -march=native
	#FFLAGS+=-O1 -march=native
	#FFLAGS+=-O2 -march=native
	FFLAGS+=-O3 -march=native
endif # DEBUG

ifeq ($(LINK_OPTIM),1)
	FFLAGS+=-flto
	LDFLAGS+=-flto
	VERSION:=$(VERSION)_lto
endif # INLINING

PREPROC+=-D_FC_GNU_
