# Copyright © 2016 CNRS,
# Copyright © 2016 Université de Nantes.
# Author: Florian Blachère
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

# Name of the binary
APP?=AdmAP2D
# Physics used: ADV, BURGERS, EULER, M1, P1, SW, TELE
PHY?=ADV
# Numerical flux: RUS, HLL, HLLC
FLUX?=RUS
# Time scheme: FE (Forward Euler), SSPRK22, SSPRK33, RK3TVD
TIME?=FE
PREPROC+=-D_TIME_$(TIME)_ -D_TIME_='"$(TIME)"'

# Number of groups in the multigroup M1 model
ifeq ($(PHY), M1MG)
	M1MG_NB_GROUP?=6
	_PHY_OPT:=$(_PHY_OPT)_$(M1MG_NB_GROUP)
	PREPROC+=-D_PHY_M1MG_NB_GROUP_=$(M1MG_NB_GROUP)
endif # PHY, M1MG

# Enable the source term?
ifneq ($(PHY), ADV)
ifneq ($(PHY), BURGERS)
ifeq ($(SRC), 1)
			PREPROC+=-D_SRC_ENABLE_
			_PHY_OPT:=$(_PHY_OPT)_Src
endif # SRC
endif # PHY, BURGERS
endif # PHY, ADV

ifeq ($(PHY), EULER)
ifeq ($(SRC), 1)
		PREPROC+=-D_PHY_EULER_ISENTROPIC_
else
ifeq ($(PHY_EULER_ISENTROPIC), 1)
			PREPROC+=-D_PHY_EULER_ISENTROPIC_
			_PHY_OPT:=$(_PHY_OPT)_Is
else
			PREPROC+=-D_PHY_EULER_IDEAL_GAS_
endif # PHY_EULER_IS
endif # SRC
endif # PHY, EULER

PREPROC+=-D_PHY_$(PHY)_ -D_PHY_='"$(PHY)$(_PHY_OPT)"'

# Number of points for the DLP reconstruction
ifneq ($(TP_FLUX), 1)
	DLP_NB_PT_INTERP?=3
	PREPROC+=-D_DLP_NB_PT_INTERP_=$(DLP_NB_PT_INTERP)
	_FLUX_OPT:=$(_FLUX_OPT)_DLP$(DLP_NB_PT_INTERP)
endif # TP_FLUX

# Use the correction with the two-points flux?
ifeq ($(TP_CORREC), 1)
	PREPROC+=-D_TP_CORREC_
	_FLUX_OPT:=$(_FLUX_OPT)_TPCorrec
endif # TP_CORREC

# Use the two-points flux as primary flux?
ifeq ($(TP_FLUX), 1)
	PREPROC+=-D_TP_FLUX_
	_FLUX_OPT:=$(_FLUX_OPT)_TPFlux
endif # TP_FLUX

ifeq ($(SRC), 1)
ifeq ($(FLUX_SRC_CENTER), 1)
		PREPROC+=-D_FLUX_SRC_CENTER_
		_FLUX_OPT:=$(_FLUX_OPT)_SrcCenter
endif # SRC_CENTER
	# Disable the asymptotic preserving correction?
ifeq ($(NO_AP), 1)
		PREPROC+=-D_SRC_DISABLE_AP_CORREC_
		_FLUX_OPT:=$(_FLUX_OPT)_NoAP
endif # NO_AP
endif # SRC


# Enable the correction with the TP on all cells (only for debugging)?
ifeq ($(TP_CORREC_FULL), 1)
	PREPROC+=-D_TP_CORREC_ -D_TP_CORREC_FULL_
	_FLUX_OPT:=$(_FLUX_OPT)_TPCorrecFull
endif # TP_CORREC_FULL

PREPROC+=-D_FLUX_$(FLUX)_ -D_FLUX_='"$(FLUX)$(_FLUX_OPT)"'

# Enable the restart file?
DUMP?=0
ifeq ($(DUMP),1)
		PREPROC+=-D_IO_ENABLE_DUMP_
endif # DUMP

# Write the solution in VTK files?
VTK?=1
ifeq ($(VTK),1)
	PREPROC+=-D_IO_ENABLE_VTK_
endif # VTK

# The given .msh file is the diamond mesh (D2P) or the primary mesh (P2D)?
MESH?=P2D
ifeq ($(MESH),P2D)
# Enable the RCM algorithm?
ifeq ($(RCM),1)
		_MESH_OPT:=$(_MESH_OPT)_RCM
		PREPROC+=-D_MESH_RCM_
endif # RCM
# Does the mesh contains periodic bnd conditions?
ifeq ($(PERIODIC),1)
		_MESH_OPT:=$(_MESH_OPT)_Per
		PREPROC+=-D_MESH_PERIODIC_
endif # PERIODIC
endif # P2D
PREPROC+=-D_MESH_$(MESH)_ -D_MESH_='"$(MESH)$(_MESH_OPT)"'

# Use the high order version of the code using MOOD
MOOD?=-1
ifeq ($(MOOD),-1)
	# Degree 0, scheme of order one
	HO=NoHO
else
	# HO with a polynomial reconstruction of order $(MOOD)
	# which leads to a scheme of order $(MOOD)+1

	HO=MOOD_P$(MOOD)

	# Unlimited version of MOOD?
ifeq ($(MOOD_UNLIMITED),1)
		HO:=$(HO)_Ulimit
		PREPROC+=-D_HO_MOOD_UNLIMITED_
else # MOOD_UNLIMITED

		# Physical Admissibilty Detector (PAD)
		MOOD_PAD?=1
ifeq ($(MOOD_PAD),1)
			HO:=$(HO)_PAD
			PREPROC+=-D_HO_MOOD_PAD_
endif # MOOD_PAD

		# Discrete Maximum Principle (DMP)
		MOOD_DMP?=0
ifeq ($(MOOD_DMP),1)
			HO:=$(HO)_DMP
			PREPROC+=-D_HO_MOOD_DMP_
endif # MOOD_DMP

		# Extrema Detector (ED)
		MOOD_ED?=0
ifeq ($(MOOD_ED),1)
			HO:=$(HO)_ED
			PREPROC+=-D_HO_MOOD_ED_
endif # MOOD_ED

ifneq (,$(filter 1, $(MOOD_DMP) $(MOOD_ED)))
			# Detection of smooth extremas (u2)
			MOOD_U2?=0
ifeq ($(MOOD_U2),1)
				HO:=$(HO)_u2
				PREPROC+=-D_HO_MOOD_U2_
endif # MOOD_U2
endif # MOOD_DMP or MOOD_ED

		# Entropic criterion
ifneq (,$(filter $(PHY), EULER SW))
ifeq ($(MOOD_ENTROPIC),1)
			HO:=$(HO)_Ent
			PREPROC+=-D_HO_MOOD_ENTROPIC_
endif # MOOD_ENTROPIC
endif # EULER SW

		# Check the polynomial reconstruction
		MOOD_CHECK_POLY_REC?=0
ifeq ($(MOOD_CHECK_POLY_REC),1)
			HO:=$(HO)_CPR
			PREPROC+=-D_HO_MOOD_CHECK_POLY_REC_
endif # MOOD_ENTROPIC

endif # MOOD_UNLIMITED

	# Decrease all the cells degree to the minimal degree
ifeq ($(MOOD_FULL_DEC),1)
		HO:=$(HO)Dec
		PREPROC+=-D_HO_MOOD_FULL_DEC_
endif # MOOD_FULL_DEC

	PREPROC+=-D_HO_='"$(HO)"' -D_HO_MOOD_ -D_HO_$(HO)_ -D_HO_MOOD_MAX_DEGREE_=$(MOOD)

	#LAPACK is needed for the HO scheme (especially DGESVD())
ifeq ($(FC_FAMILY), intel)
		MKL=1
else
ifeq ($(shell [ -e /usr/lib/libopenblas.so ] && echo 1), 1)
			OPENBLAS=1
else
			BLAS=1
endif # OpenBLAS
endif # MKL

	MOOD_MATRIX_SCALING?=1
ifeq ($(MOOD_MATRIX_SCALING),1)
		PREPROC+=-D_HO_MOOD_MATRIX_SCALING_
endif # MOOD_MATRIX_SCALING

endif # MOOD

# Informations about the compilation
INFO=$(APP)-$(PHY)$(_PHY_OPT)-$(FLUX)$(_FLUX_OPT)-$(TIME)-$(HO)-$(MESH)$(_MESH_OPT)-$(ARCH)
