#!/bin/bash
# Copyright © 2016 CNRS,
# Copyright © 2016 Université de Nantes.
# Author: Florian Blachère
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

## Script to compile the code with the different options

#######################################################################
## Code configuration
#######################################################################
# Name of the binary
CODE=AdmAP2D
# Physics used: ADV, BURGERS, EULER, HYDRORAD, HYPHEAT, M1, M1MG, P1, SW, TELE
PHY=EULER
_PHY_OPT=_Src
# Time integrators: FE, SSPRK22, SSPRK33, SSPRK54, ...
TIME=SSPRK22
#
ORDER=MOOD_P1_PAD
# Numerical flux: RUS, HLL, HLLC
FLUX=HLL
DLP_NB_PT_INTERP=3
_FLUX_OPT=_DLP${DLP_NB_PT_INTERP}_TPCorrec
# Way to create the mesh: Primary to Diamond (P2D) or Diamond to Primary (D2P)
MESH=P2D
_MESH_OPT=_RCM
#
ARCH=$(uname -m)
# Fortran compiler
FC=gnu
_FC_OPT=_omp
# Destination directory
#DESTDIR=~/work/runs/${CODE}/${PHY}${_PHY_OPT}-${ORDER}/${DESTDIR_OPT}
DESTDIR=./runs
DESTDIR=$(readlink -m "${DESTDIR}")
#######################################################################


#######################################################################
## Compile
#######################################################################
make -j4 \
  PHY=${PHY} FLUX=${FLUX} \
  PHY_EULER_ISENTROPIC=0 M1MG_NB_GROUP=6 \
  MOOD=1  \
  MOOD_UNLIMITED=0 MOOD_PAD=1 MOOD_DMP=0 MOOD_ED=0 MOOD_U2=0 MOOD_ENTROPIC=0 \
  MOOD_FULL_DEC=0 MOOD_CHECK_POLY_REC=0 \
  TIME=${TIME} \
  TP_CORREC=1 TP_FLUX=0 TP_CORREC_FULL=0 \
  SRC=1 FLUX_SRC_CENTER=0 NO_AP=0 \
  MESH=${MESH} RCM=1 PERIODIC=0 \
  DLP_NB_PT_INTERP=${DLP_NB_PT_INTERP} \
  OMP=1 DEBUG=0 LINK_OPTIM=0 \
  OMPP=0 SCALASCA=0 PROFILING=0 COVERAGE=0 \
  DUMP=1 HDF5=0 NC=0 VTK=1 \
  DESTDIR="${DESTDIR}"
#######################################################################

exit 0
