#!/bin/bash
# Copyright © 2016 CNRS,
# Copyright © 2016 Université de Nantes.
# Author: Florian Blachère
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

## Compile everything and see if there is trouble

#Color and bold
red="\e[31m\e[1m"
reset="\e[0m"

NbTests=1

if [[ ${FULL_TEST} -eq 1 ]]
then
  PHYs=('ADV' 'BURGERS' 'EULER' 'HYDRORAD' 'HYPHEAT' 'M1' 'M1MG' 'P1' 'SW' 'TELE')
  FLUXs=('RUS' 'HLL' 'HLLC')
  TIMEs=('FE' 'SSPRK22' 'SSPRK33' 'RK3TVD' 'SSPRK54')
  MESHs=('D2P' 'P2D')
  RCMs=('0' '1')
  OMPs=('0' '1')
  DUMPs=('0' '1')
  VTKs=('0' '1')
  SRCs=('0' '1')
  NO_APs=('0' '1')
  TP_FLUXs=('0' '1')
  TP_CORRECs=('0' '1')
  TP_CORREC_FULLs=('0' '1')
  MOODs=('-1' '0' '1' '2' '3' '4' '5')
  MOOD_UNLIMITEDs=('0' '1')
  MOOD_PADs=('0' '1')
  MOOD_DMPs=('0' '1')
  MOOD_EDs=('0' '1')
  MOOD_U2s=('0' '1')
  MOOD_ENTROPICs=('0' '1')
else
  PHYs=('HYDRORAD')
  FLUXs=('HLL')
  TIMEs=('SSPRK54')
  MESHs=('P2D')
  RCMs=('1')
  OMPs=('1')
  DUMPs=('1')
  VTKs=('1')
  SRCs=('0' '1')
  NO_APs=('0')
  TP_FLUXs=('0')
  TP_CORRECs=('1')
  TP_CORREC_FULLs=('0')
  MOODs=('5')
  MOOD_UNLIMITEDs=('0')
  MOOD_PADs=('1')
  MOOD_DMPs=('1')
  MOOD_EDs=('0')
  MOOD_U2s=('1')
  MOOD_ENTROPICs=('1')
fi

TotTests="$((${#PHYs[@]} * ${#FLUXs[@]} * ${#TIMEs[@]} * ${#MESHs[@]} * ${#RCMs[@]} * ${#OMPs[@]} * ${#DUMPs[@]} * ${#VTKs[@]} * ${#SRCs[@]} * ${#NO_APs[@]} * ${#TP_FLUXs[@]} * ${#TP_CORRECs[@]} * ${#TP_CORREC_FULLs[@]} * ${#MOODs[@]} * ${#MOOD_UNLIMITEDs[@]} * ${#MOOD_PADs[@]} * ${#MOOD_DMPs[@]} * ${#MOOD_EDs[@]} * ${#MOOD_U2s[@]} * ${#MOOD_ENTROPICs[@]}))"

echo "Running ${TotTests} tests"
echo "======================================"

TESTDIR=./tests
MAKEFLAGS=-j$(nproc)

rm -rf "${TESTDIR}"
mkdir -p "${TESTDIR}"

for PHY in "${PHYs[@]}"; do
  for FLUX in "${FLUXs[@]}" ; do
    for TIME in "${TIMEs[@]}" ; do
      for MESH in "${MESHs[@]}" ; do
        for RCM in "${RCMs[@]}" ; do
          for OMP in "${OMPs[@]}" ; do
            for DUMP in "${DUMPs[@]}" ; do
              for VTK in "${VTKs[@]}"; do
                for SRC in "${SRCs[@]}" ; do
                  for NO_AP in "${NO_APs[@]}" ; do
                    for TP_FLUX in "${TP_FLUXs[@]}" ; do
                      for TP_CORREC_FULL in "${TP_CORREC_FULLs[@]}" ; do
                        for TP_CORREC in "${TP_CORRECs[@]}" ; do
                          for MOOD in "${MOODs[@]}" ; do
                            for MOOD_UNLIMITED in "${MOOD_UNLIMITEDs[@]}" ; do
                              for MOOD_PAD in "${MOOD_PADs[@]}" ; do
                                for MOOD_DMP in "${MOOD_DMPs[@]}" ; do
                                  for MOOD_ED in "${MOOD_EDs[@]}" ; do
                                    for MOOD_U2 in "${MOOD_U2s[@]}" ; do
                                      for MOOD_ENTROPIC in "${MOOD_ENTROPICs[@]}" ; do

                                        logfile="${TESTDIR}/${PHY}-${FLUX}-${TIME}-${MESH}_RCM${RCM}-OMP${OMP}-DUMP${DUMP}-VTK${VTK}-Src${SRC}_NoAP${NO_AP}-TPFlux${TP_FLUX}_TPCorrec${TP_CORREC}_TPCorrecFull${TP_CORREC_FULL}-MOOD${MOOD}_Ulimi${MOOD_UNLIMITED}_PAD${MOOD_PAD}_DMP${MOOD_DMP}_ED${MOOD_ED}_u2${MOOD_U2}_Ent${MOOD_ENTROPIC}.log"
                                        echo -e "Compiling ${logfile} ..."
                                        echo -e "Test ${NbTests}/${TotTests}"

                                        if [[ ! -e /.dockerinit ]]
                                        then
                                          # Continue on failure and print errors in logs
                                          make "${MAKEFLAGS}" \
                                            PHY="${PHY}" FLUX="${FLUX}" \
                                            PHY_EULER_ISENTROPIC=0 \
                                            MOOD="${MOOD}"  \
                                            MOOD_UNLIMITED="${MOOD_UNLIMITED}" MOOD_PAD="${MOOD_PAD}" \
                                            MOOD_DMP="${MOOD_DMP}" MOOD_ED="${MOOD_ED}" \
                                            MOOD_U2="${MOOD_U2}" MOOD_ENTROPIC="${MOOD_ENTROPIC}" \
                                            MOOD_FULL_DEC=0 MOOD_CHECK_POLY_REC=0 \
                                            TIME="${TIME}" \
                                            TP_FLUX="${TP_FLUX}" TP_CORREC="${TP_CORREC}" TP_CORREC_FULL="${TP_CORREC_FULL}" \
                                            SRC="${SRC}" FLUX_SRC_CENTER=0 NO_AP="${NO_AP}" \
                                            MESH="${MESH}" RCM="${RCM}" PERIODIC=1 \
                                            DLP_NB_PT_INTERP=3 \
                                            OMP="${OMP}" DEBUG=1 \
                                            OMPP=0 SCALASCA=0 PROFILING=0 COVERAGE=0 \
                                            DUMP="${DUMP}" VTK="${VTK}" \
                                            DESTDIR="${TESTDIR}" \
                                            &> "${logfile}" \
                                            || echo -e "${red}failed${reset} see ${logfile}"
                                        else
                                          # Stop on failure and print log on stdout
                                          make "${MAKEFLAGS}" \
                                            PHY="${PHY}" FLUX="${FLUX}" \
                                            PHY_EULER_ISENTROPIC=0 \
                                            MOOD="${MOOD}"  \
                                            MOOD_UNLIMITED="${MOOD_UNLIMITED}" MOOD_PAD="${MOOD_PAD}" \
                                            MOOD_DMP="${MOOD_DMP}" MOOD_ED="${MOOD_ED}" \
                                            MOOD_U2="${MOOD_U2}" MOOD_ENTROPIC="${MOOD_ENTROPIC}" \
                                            MOOD_FULL_DEC=0 MOOD_CHECK_POLY_REC=0 \
                                            TIME="${TIME}" \
                                            TP_FLUX="${TP_FLUX}" TP_CORREC="${TP_CORREC}" TP_CORREC_FULL="${TP_CORREC_FULL}" \
                                            SRC="${SRC}" NO_AP="${NO_AP}" \
                                            MESH="${MESH}" RCM="${RCM}" PERIODIC=1 \
                                            DLP_NB_PT_INTERP=3 \
                                            OMP="${OMP}" DEBUG=1 \
                                            OMPP=0 SCALASCA=0 PROFILING=0 COVERAGE=0 \
                                            DUMP="${DUMP}" VTK="${VTK}" \
                                            DESTDIR="${TESTDIR}" || exit 1
                                        fi
                                        NbTests="$((NbTests + 1))"

                                        rm -r -- "${TESTDIR}"/build*

                                      done
                                    done
                                  done
                                done
                              done
                            done
                          done
                        done
                      done
                    done
                  done
                done
              done
            done
          done
        done
      done
    done
  done
done

echo "All tests done"

exit 0
