!> Some parameters for the I/O
!>
!> @author Florian Blachère
!>
!> @copyright © 2016 CNRS,
!> @copyright © 2016 Université de Nantes.
!> @copyright This program is free software: you can redistribute it and/or modify
!> it under the terms of the GNU General Public License as published by
!> the Free Software Foundation, either version 3 of the License, or
!> (at your option) any later version.
!>
!> @copyright This program is distributed in the hope that it will be useful,
!> but WITHOUT ANY WARRANTY; without even the implied warranty of
!> MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!> GNU General Public License for more details.
!>
!> @copyright You should have received a copy of the GNU General Public License
!> along with this program.  If not, see <http://www.gnu.org/licenses/>.
module type_IO

  use, INTRINSIC :: ISO_FORTRAN_ENV, only: OUTPUT_UNIT, ERROR_UNIT

  implicit none

  !> Outputs on screen are done every \c out_screen %
  integer, parameter :: out_screen = 1
  !> Outputs on disk (VTK files) are done every \c out_disk %
  integer, parameter :: out_disk = 5
#if defined(_IO_ENABLE_DUMP_)
  !> Dumps are done every \c dump_disk %
  integer, parameter :: dump_disk = 5
#endif /* _IO_ENABLE_DUMP_ */

#if defined(_IO_ENABLE_VTK_)
  !> Number of outputs to the disk
  integer, save :: n_out_disk
#endif /* _IO_ENABLE_VTK_ */
  !> Number of outputs to the screen (log)
  integer, save :: n_out_screen
#if defined(_IO_ENABLE_DUMP_)
  !> Number of dumps (for restart file)
  integer  :: n_dump_disk
#endif /* _IO_ENABLE_DUMP_ */

  !> Standard output (6)
  integer, parameter :: StdOut = OUTPUT_UNIT
  !> Standard error (0)
  integer, parameter :: StdErr = ERROR_UNIT

  !> Format definition for double, which could write '-1.2345E-123'
  character(len=8), parameter :: FMT_D = 'ES12.4E3'
  !> Format definition for integer
  character(len=2), parameter :: FMT_I = 'I9'

end module type_IO
