!> Physics module for the advection equation.
!>
!> \f[ \partial_t u + \text{div}(\vec{a} u) = 0\f]
!> where \f$\vec{a}\f$ is the speed of the advection.
!>
!> @author Florian Blachère
!>
!> @copyright © 2016 CNRS,
!> @copyright © 2016 Université de Nantes.
!> @copyright This program is free software: you can redistribute it and/or modify
!> it under the terms of the GNU General Public License as published by
!> the Free Software Foundation, either version 3 of the License, or
!> (at your option) any later version.
!>
!> @copyright This program is distributed in the hope that it will be useful,
!> but WITHOUT ANY WARRANTY; without even the implied warranty of
!> MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!> GNU General Public License for more details.
!>
!> @copyright You should have received a copy of the GNU General Public License
!> along with this program.  If not, see <http://www.gnu.org/licenses/>.
module mod_physics_Advection_var
#if defined (_PHY_ADV_)

  use mod_numerics, only: PR, MaxLen
  use type_mesh, only: dim_

  IMPLICIT NONE

  private
  public NbEq, NbEq_str,  T_end
  public len_model, len_primitive, len_conservative
  public model_name, primitive_name, conservative_name, test_case

  public speed_adv

  integer, parameter :: len_model = 9
  !> Name of the model
  character(len=len_model), parameter :: model_name = 'Advection'
  !> Number of equations (unknowns) in the model
  integer, parameter :: NbEq = 1
  !> Number of equations (unknowns) in the model, in a string
  character(len=1), parameter :: NbEq_str = '1'

  !> Vector of advection
  real(PR), dimension(dim_), save :: speed_adv

  !> Final time of the simulation
  real(PR), parameter :: T_end = 1.0_PR

  integer, parameter :: len_primitive    = 1
  integer, parameter :: len_conservative = 1

  !> Primitive variables used in the model
  character(len=len_primitive),    dimension(NbEq), parameter :: primitive_name    = ['u']
  !> Conservative variables used in the model
  character(len=len_conservative), dimension(NbEq), parameter :: conservative_name = ['u']

  !> Name of the test case
  character(len=MaxLen), save :: test_case

#endif /* _PHY_ADV_ */
end module mod_physics_Advection_var
