!> Physics module for the inviscid Burgers equation.
!>
!> \f[ \partial_t u + \partial_x \frac{u^2}{2} + \partial_y \frac{u^2}{2}= 0. \f]
!>
!> @author Florian Blachère
!>
!> @copyright © 2016 CNRS,
!> @copyright © 2016 Université de Nantes.
!> @copyright This program is free software: you can redistribute it and/or modify
!> it under the terms of the GNU General Public License as published by
!> the Free Software Foundation, either version 3 of the License, or
!> (at your option) any later version.
!>
!> @copyright This program is distributed in the hope that it will be useful,
!> but WITHOUT ANY WARRANTY; without even the implied warranty of
!> MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!> GNU General Public License for more details.
!>
!> @copyright You should have received a copy of the GNU General Public License
!> along with this program.  If not, see <http://www.gnu.org/licenses/>.
module mod_physics_Burgers_var
#if defined(_PHY_BURGERS_)

  use mod_numerics, only: PR, MaxLen

  IMPLICIT NONE

  private
  public NbEq, NbEq_str, T_end
  public len_model, len_primitive, len_conservative
  public model_name, primitive_name, conservative_name, test_case

  integer, parameter                  :: len_model = 7
  !> Name of the model
  character(len=len_model), parameter :: model_name = 'Burgers'
  !> Number of equations (unknowns) in the model
  integer, parameter                  :: NbEq = 1
  !> Number of equations (unknowns) in the model, in a string
  character(len=1), parameter :: NbEq_str = '1'

  !> Final time of the simulation
  real(PR), parameter :: T_end = 2._PR

  integer, parameter :: len_primitive    = 1
  integer, parameter :: len_conservative = 1

  !> Primitive variables used in the model
  character(len=len_primitive),    dimension(NbEq), parameter :: primitive_name    = ['u']
  !> Conservative variables used in the model
  character(len=len_conservative), dimension(NbEq), parameter :: conservative_name = ['u']

  !> Name of the test case
  character(len=MaxLen), save :: test_case

#endif /* _PHY_BURGERS_ */
end module mod_physics_Burgers_var
