!> Wrapper used to choose the physics of the problem
!>
!> @author Florian Blachère
!>
!> @copyright © 2016 CNRS,
!> @copyright © 2016 Université de Nantes.
!> @copyright This program is free software: you can redistribute it and/or modify
!> it under the terms of the GNU General Public License as published by
!> the Free Software Foundation, either version 3 of the License, or
!> (at your option) any later version.
!>
!> @copyright This program is distributed in the hope that it will be useful,
!> but WITHOUT ANY WARRANTY; without even the implied warranty of
!> MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!> GNU General Public License for more details.
!>
!> @copyright You should have received a copy of the GNU General Public License
!> along with this program.  If not, see <http://www.gnu.org/licenses/>.

module mod_physics_var

#if defined(_PHY_ADV_)
  use mod_physics_Advection_var, only: NbEq, NbEq_str, T_end
  use mod_physics_Advection_var, only: len_model, len_primitive, len_conservative
  use mod_physics_Advection_var, only: model_name, primitive_name, conservative_name, test_case
#elif defined(_PHY_BURGERS_)
  use mod_physics_Burgers_var, only: NbEq, NbEq_str, T_end
  use mod_physics_Burgers_var, only: len_model, len_primitive, len_conservative
  use mod_physics_Burgers_var, only: model_name, primitive_name, conservative_name, test_case
#elif defined(_PHY_EULER_)
  use mod_physics_Euler_var, only: NbEq, NbEq_str, T_end
  use mod_physics_Euler_var, only: len_model, len_primitive, len_conservative
  use mod_physics_Euler_var, only: model_name, primitive_name, conservative_name, test_case
#elif defined(_PHY_HYDRORAD_)
  use mod_physics_HydroRad_var, only: NbEq, NbEq_str, T_end
  use mod_physics_HydroRad_var, only: len_model, len_primitive, len_conservative
  use mod_physics_HydroRad_var, only: model_name, primitive_name, conservative_name, test_case
#elif defined(_PHY_HYPHEAT_)
  use mod_physics_HypHeat_var, only: NbEq, NbEq_str, T_end
  use mod_physics_HypHeat_var, only: len_model, len_primitive, len_conservative
  use mod_physics_HypHeat_var, only: model_name, primitive_name, conservative_name, test_case
#elif defined(_PHY_M1_)
  use mod_physics_M1_var, only: NbEq, NbEq_str, T_end
  use mod_physics_M1_var, only: len_model, len_primitive, len_conservative
  use mod_physics_M1_var, only: model_name, primitive_name, conservative_name, test_case
#elif defined(_PHY_M1MG_)
  use mod_physics_M1MG_var, only: NbEq, NbEq_str, T_end
  use mod_physics_M1MG_var, only: len_model, len_primitive, len_conservative
  use mod_physics_M1MG_var, only: model_name, primitive_name, conservative_name, test_case
#elif defined(_PHY_P1_)
  use mod_physics_P1_var, only: NbEq, NbEq_str, T_end
  use mod_physics_P1_var, only: len_model, len_primitive, len_conservative
  use mod_physics_P1_var, only: model_name, primitive_name, conservative_name, test_case
#elif defined(_PHY_SW_)
  use mod_physics_SW_var, only: NbEq, NbEq_str, T_end
  use mod_physics_SW_var, only: len_model, len_primitive, len_conservative
  use mod_physics_SW_var, only: model_name, primitive_name, conservative_name, test_case
#elif defined(_PHY_TELE_)
  use mod_physics_Telegraph_var, only: NbEq, NbEq_str, T_end
  use mod_physics_Telegraph_var, only: len_model, len_primitive, len_conservative
  use mod_physics_Telegraph_var, only: model_name, primitive_name, conservative_name, test_case
#endif /* _PHY_ */

  use mod_numerics, only: MaxLen

  IMPLICIT NONE

  private
  public NbEq, NbEq_str, T_end
  public len_model, len_primitive, len_conservative
  public model_name, primitive_name, conservative_name, test_case
  public Output_Directory

  !> Output directory for the current test case.
  character(len=MaxLen) :: Output_Directory

end module mod_physics_var
