!> Some tools to print vectors and matrices
!>
!> @author Florian Blachère
!>
!> @copyright © 2016 CNRS,
!> @copyright © 2016 Université de Nantes.
!> @copyright This program is free software: you can redistribute it and/or modify
!> it under the terms of the GNU General Public License as published by
!> the Free Software Foundation, either version 3 of the License, or
!> (at your option) any later version.
!>
!> @copyright This program is distributed in the hope that it will be useful,
!> but WITHOUT ANY WARRANTY; without even the implied warranty of
!> MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!> GNU General Public License for more details.
!>
!> @copyright You should have received a copy of the GNU General Public License
!> along with this program.  If not, see <http://www.gnu.org/licenses/>.
module mod_tools_print

  use mod_numerics, only: PR
  use type_IO, only: StdOut

  IMPLICIT NONE

  !> Print a vector of integers or reals
  interface PrintVector
    module procedure PrintVectorReal, PrintVectorInteger
  end interface

contains
  !--------------------------------------------------------------------------
  !> @brief
  !> Print a real matrix in a nice way
  !>
  !> @param[in] A Real matrix
  !> @param[in] n Number of rows in the matrix
  !>
  !> @author Florian Blachère
  !--------------------------------------------------------------------------
  subroutine PrintMatrix(n,A)
    integer, intent(in) :: n
    real(PR), dimension(:,:), intent(in) :: A

#if defined(_FC_GNU_)
    character(len=8) :: FMT8
    WRITE(FMT8,'(I8)') n
    write(StdOut,"("//trim(FMT8)//"(ES11.4,1X))") transpose(A)
#elif defined(_FC_INTEL_)
10 FORMAT(<n>(ES11.4,1X))
    write(StdOut,10) transpose(A)
#endif /* _FC_ */

  end subroutine PrintMatrix

  !--------------------------------------------------------------------------
  !> @brief
  !> Print a real vector in a nice way
  !>
  !> @param[in] x Real vector
  !> @param[in] n Number of rows in the vector
  !>
  !> @author Florian Blachère
  !--------------------------------------------------------------------------
  subroutine PrintVectorReal(n,x)
    integer, intent(in) :: n
    real(PR), dimension(:), intent(in) :: x

#if defined(_FC_GNU_)
    character(len=8) :: FMT8
    WRITE(FMT8,'(I8)') n
    write(StdOut,"("//trim(FMT8)//"(ES11.4,1X))") x(1:n)
#elif defined(_FC_INTEL_)
10 FORMAT(<n>(ES11.4,1X))
    write(StdOut,10) x(1:n)
#endif /* _FC_ */

  end subroutine PrintVectorReal

  !--------------------------------------------------------------------------
  !> @brief
  !> Print an integer vector in a nice way
  !>
  !> @param[in] x Integer vector
  !> @param[in] n Number of rows in the vector
  !>
  !> @author Florian Blachère
  !--------------------------------------------------------------------------
  subroutine PrintVectorInteger(n,x)
    integer, intent(in) :: n
    integer, dimension(:), intent(in) :: x

#if defined(_FC_GNU_)
    character(len=8) :: FMT8
    WRITE(FMT8,'(I8)') n
    write(StdOut,"("//trim(FMT8)//"(I9,1X))") x(1:n)
#elif defined(_FC_INTEL_)
10 FORMAT(<n>(I9,1X))
    write(StdOut,10) x(1:n)
#endif /* _FC_ */

  end subroutine PrintVectorInteger

end module mod_tools_print
