!> Some tools to swap things
!>
!> @author Florian Blachère
!>
!> @copyright © 2016 CNRS,
!> @copyright © 2016 Université de Nantes.
!> @copyright This program is free software: you can redistribute it and/or modify
!> it under the terms of the GNU General Public License as published by
!> the Free Software Foundation, either version 3 of the License, or
!> (at your option) any later version.
!>
!> @copyright This program is distributed in the hope that it will be useful,
!> but WITHOUT ANY WARRANTY; without even the implied warranty of
!> MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
!> GNU General Public License for more details.
!>
!> @copyright You should have received a copy of the GNU General Public License
!> along with this program.  If not, see <http://www.gnu.org/licenses/>.
module mod_tools_swap

  use mod_numerics, only: PR
  use type_IO, only: StdErr

  implicit none

  private
  public Swap

  !> Swap integers, reals, or strings
  interface Swap
    module procedure IntSwap, RealSwap, StrSwap
  end interface

contains
  !--------------------------------------------------------------------------
  !> @brief
  !> Swap two integers
  !>
  !> @param[in,out] a,b Two integers
  !>
  !> @author Florian Blachère
  !--------------------------------------------------------------------------
  subroutine IntSWAP(a, b)
    integer, intent(in out) :: a, b
    integer :: tmp
    tmp = a
    a = b
    b = tmp
  end subroutine IntSWAP

  !--------------------------------------------------------------------------
  !> @brief
  !> Swap two reals
  !>
  !> @param[in,out] a,b Two reals
  !>
  !> @author Florian Blachère
  !--------------------------------------------------------------------------
  subroutine RealSWAP(a, b)
    real(PR), intent(in out) :: a, b
    real(PR) :: tmp
    tmp = a
    a = b
    b = tmp
  end subroutine RealSWAP

  !--------------------------------------------------------------------------
  !> @brief
  !> Swap two strings of same length
  !>
  !> @param[in,out] a,b Two strings
  !>
  !> @author Florian Blachère
  !--------------------------------------------------------------------------
  subroutine StrSWAP(a, b)
    character(*), intent(in out) :: a, b
    character(len(a)) :: tmp

    if (len(a) /= len(b)) then
      write(StdErr,'(2A,I4,A)')__FILE__,':', __LINE__, " -> Trouble to swap strings, not the same length."
      FLUSH StdErr
      STOP
    else
      tmp = a
      a = b
      b = tmp
    end if
  end subroutine StrSWAP

end module mod_tools_swap
